WANDBResultTracker
==================

.. currentmodule:: pykeen.trackers

.. autoclass:: WANDBResultTracker
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~WANDBResultTracker.log_metrics
      ~WANDBResultTracker.log_params

   .. rubric:: Methods Documentation

   .. automethod:: log_metrics
   .. automethod:: log_params
